package com.qq.lezi2012.cmslite.service.impl;


import com.qq.lezi2012.cmslite.AppProperties;
import com.qq.lezi2012.cmslite.dao.CategoryMapper;
import com.qq.lezi2012.cmslite.dao.ContentMapper;
import com.qq.lezi2012.cmslite.dao.UserMapper;
import com.qq.lezi2012.cmslite.dao.WidgetCodeMapper;
import com.qq.lezi2012.cmslite.model.CommonCallback;
import com.qq.lezi2012.cmslite.model.def.ResponseCode;
import com.qq.lezi2012.cmslite.model.exception.BizException;
import com.qq.lezi2012.cmslite.model.vo.BaseResponse;
import com.qq.lezi2012.cmslite.utils.TXUtils;
import com.qq.lezi2012.cmslite.model.exception.BaseException;
import org.apache.log4j.Logger;
import org.mybatis.spring.SqlSessionTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.support.TransactionTemplate;

import javax.annotation.Resource;

public abstract class BaseServiceImpl {

    @Autowired
    protected ContentMapper contentDao;

    @Autowired
    protected CategoryMapper categoryDao;

    @Autowired
    protected UserMapper userDao;

    @Autowired
    protected WidgetCodeMapper widgetCodeDao;

    private static Logger LOGGER = Logger.getLogger(BaseServiceImpl.class);

    @Autowired
    public AppProperties appProperties;

    @Resource(name = "sharedTransactionTemplate")
    protected TransactionTemplate transactionTemplate;

    @Autowired
    protected SqlSessionTemplate sqlSessionTemplate;


    protected <M extends BaseResponse> M execute(CommonCallback commonCallback, M response) {
        try {
            response.result = commonCallback.exec();
        } catch (BaseException e) {
            LOGGER.info(e.message);
            response.respondTo(e);
        } catch (Exception e) {
            LOGGER.error(e.getMessage(), e);
            response.respondTo(ResponseCode.SYS_ERROR);
        }
        return response;
    }


    public void test(){

    }

    protected BaseResponse execute(CommonCallback commonCallback) {
        return execute(commonCallback, new BaseResponse());
    }


    protected void bizError(ResponseCode responseCode) throws BizException {
        throw new BizException(responseCode);
    }

    protected void checkResponse(BaseResponse response) throws BizException {
        if (!response.success())
            bizError(response.code);
    }



    protected Object withTransaction(final CommonCallback commonCallback) throws BaseException {
        return TXUtils.withTransaction(transactionTemplate, commonCallback);
    }


}
