package com.qq.lezi2012.cmslite.service.impl;


import com.google.common.collect.ImmutableMap;
import com.qq.lezi2012.cmslite.dao.CustContentMapper;
import com.qq.lezi2012.cmslite.domain.Content;
import com.qq.lezi2012.cmslite.domain.CustContentExample;
import com.qq.lezi2012.cmslite.model.CommonCallback;
import com.qq.lezi2012.cmslite.model.exception.BaseException;
import com.qq.lezi2012.cmslite.model.vo.BaseResponse;
import com.qq.lezi2012.cmslite.service.ContentService;
import org.apache.commons.io.FileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.List;

@Service
public class ContentServiceImpl extends BaseServiceImpl implements ContentService {


    @Autowired
    public CustContentMapper custContentMapper;

    public BaseResponse save(final Content content) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                contentDao.insert(content);
                return content;
            }
        });
    }

    public BaseResponse update(final Content instance) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                contentDao.updateByPrimaryKeySelective(instance);
                return instance;
            }
        }, new BaseResponse());
    }

    public BaseResponse delete(final String id) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                BaseResponse baseResponse = get(id);
                checkResponse(baseResponse);
                Content content = (Content) baseResponse.result;
                String contentUploadPath = getContentUploadPath(content);
                try {
                    FileUtils.deleteDirectory(new File(contentUploadPath));
                } catch (IOException e) {
                    e.printStackTrace();
                }
                return contentDao.deleteByPrimaryKey(id);
            }
        }, new BaseResponse());
    }

    public BaseResponse get(final String id) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                return contentDao.selectByPrimaryKey(id);
            }
        }, new BaseResponse());
    }

    @Override
    public BaseResponse getContentList(final CustContentExample custContentExample) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                List<Content> list = custContentMapper.selectByExampleWithBLOBs(custContentExample);
                int count = contentDao.countByExample(custContentExample);
                return ImmutableMap.of("list", list, "total", count);
            }
        });
    }

    @Override
    public String getContentUploadPath(Content content) {
        SimpleDateFormat sdf = new SimpleDateFormat("/yyyy/MM/dd/");

        String refPath = sdf.format(content.getCreatedAt()) + content.getId();

        return appProperties.uploadRootDir + refPath;
    }
}
