package com.qq.lezi2012.cmslite.service.impl;

import com.qq.lezi2012.cmslite.domain.User;
import com.qq.lezi2012.cmslite.domain.UserExample;
import com.qq.lezi2012.cmslite.model.CommonCallback;
import com.qq.lezi2012.cmslite.model.Helper;
import com.qq.lezi2012.cmslite.model.def.ResponseCode;
import com.qq.lezi2012.cmslite.model.exception.BaseException;
import com.qq.lezi2012.cmslite.model.vo.BaseResponse;
import com.qq.lezi2012.cmslite.service.UserService;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;


@Service
public class UserServiceImpl extends BaseServiceImpl implements UserService {
    @Override
    public BaseResponse save(final User instance) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {

                if (StringUtils.isBlank(instance.getPassword()))
                    bizError(ResponseCode.USER_PASSWORD_BLANK);


                if (StringUtils.isBlank(instance.getUsername()))
                    bizError(ResponseCode.USER_USERNAME_BLANK);


                instance.setPassword(DigestUtils.md5Hex(instance.getPassword()));
                return userDao.insert(instance);
            }
        });
    }

    @Override
    public BaseResponse update(final User instance) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                if (StringUtils.isBlank(instance.getPassword()))
                    bizError(ResponseCode.USER_PASSWORD_BLANK);


                if (StringUtils.isBlank(instance.getUsername()))
                    bizError(ResponseCode.USER_USERNAME_BLANK);

                instance.setPassword(DigestUtils.md5Hex(instance.getPassword()));
                return userDao.updateByPrimaryKey(instance);
            }
        });
    }


    @Override
    public BaseResponse delete(final String id) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                return userDao.deleteByPrimaryKey(id);
            }
        });
    }

    @Override
    public BaseResponse get(final String id) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                return userDao.selectByPrimaryKey(id);
            }
        });
    }

    @Override
    public BaseResponse list() {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                UserExample userExample = new UserExample();
                return userDao.selectByExample(userExample);
            }
        });
    }

    @Override
    public BaseResponse listByExample(final UserExample userExample) {
        return execute(new CommonCallback() {
            @Override
            public Object exec() throws BaseException {
                return userDao.selectByExample(userExample);
            }
        });
    }
}
